/*******************************************************************************
* File Name: RS422_inINT.c
* Version 2.50
*
* Description:
*  This file provides all Interrupt Service functionality of the UART component
*
********************************************************************************
* Copyright 2008-2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#include "RS422_in.h"
#include "cyapicallbacks.h"


/***************************************
* Custom Declarations
***************************************/
/* `#START CUSTOM_DECLARATIONS` Place your declaration here */

/* `#END` */

#if (RS422_in_RX_INTERRUPT_ENABLED && (RS422_in_RX_ENABLED || RS422_in_HD_ENABLED))
    /*******************************************************************************
    * Function Name: RS422_in_RXISR
    ********************************************************************************
    *
    * Summary:
    *  Interrupt Service Routine for RX portion of the UART
    *
    * Parameters:
    *  None.
    *
    * Return:
    *  None.
    *
    * Global Variables:
    *  RS422_in_rxBuffer - RAM buffer pointer for save received data.
    *  RS422_in_rxBufferWrite - cyclic index for write to rxBuffer,
    *     increments after each byte saved to buffer.
    *  RS422_in_rxBufferRead - cyclic index for read from rxBuffer,
    *     checked to detect overflow condition.
    *  RS422_in_rxBufferOverflow - software overflow flag. Set to one
    *     when RS422_in_rxBufferWrite index overtakes
    *     RS422_in_rxBufferRead index.
    *  RS422_in_rxBufferLoopDetect - additional variable to detect overflow.
    *     Set to one when RS422_in_rxBufferWrite is equal to
    *    RS422_in_rxBufferRead
    *  RS422_in_rxAddressMode - this variable contains the Address mode,
    *     selected in customizer or set by UART_SetRxAddressMode() API.
    *  RS422_in_rxAddressDetected - set to 1 when correct address received,
    *     and analysed to store following addressed data bytes to the buffer.
    *     When not correct address received, set to 0 to skip following data bytes.
    *
    *******************************************************************************/
    CY_ISR(RS422_in_RXISR)
    {
        uint8 readData;
        uint8 readStatus;
        uint8 increment_pointer = 0u;

    #if(CY_PSOC3)
        uint8 int_en;
    #endif /* (CY_PSOC3) */

    #ifdef RS422_in_RXISR_ENTRY_CALLBACK
        RS422_in_RXISR_EntryCallback();
    #endif /* RS422_in_RXISR_ENTRY_CALLBACK */

        /* User code required at start of ISR */
        /* `#START RS422_in_RXISR_START` */

        /* `#END` */

    #if(CY_PSOC3)   /* Make sure nested interrupt is enabled */
        int_en = EA;
        CyGlobalIntEnable;
    #endif /* (CY_PSOC3) */

        do
        {
            /* Read receiver status register */
            readStatus = RS422_in_RXSTATUS_REG;
            /* Copy the same status to readData variable for backward compatibility support 
            *  of the user code in RS422_in_RXISR_ERROR` section. 
            */
            readData = readStatus;

            if((readStatus & (RS422_in_RX_STS_BREAK | 
                            RS422_in_RX_STS_PAR_ERROR |
                            RS422_in_RX_STS_STOP_ERROR | 
                            RS422_in_RX_STS_OVERRUN)) != 0u)
            {
                /* ERROR handling. */
                RS422_in_errorStatus |= readStatus & ( RS422_in_RX_STS_BREAK | 
                                                            RS422_in_RX_STS_PAR_ERROR | 
                                                            RS422_in_RX_STS_STOP_ERROR | 
                                                            RS422_in_RX_STS_OVERRUN);
                /* `#START RS422_in_RXISR_ERROR` */

                /* `#END` */
                
            #ifdef RS422_in_RXISR_ERROR_CALLBACK
                RS422_in_RXISR_ERROR_Callback();
            #endif /* RS422_in_RXISR_ERROR_CALLBACK */
            }
            
            if((readStatus & RS422_in_RX_STS_FIFO_NOTEMPTY) != 0u)
            {
                /* Read data from the RX data register */
                readData = RS422_in_RXDATA_REG;
            #if (RS422_in_RXHW_ADDRESS_ENABLED)
                if(RS422_in_rxAddressMode == (uint8)RS422_in__B_UART__AM_SW_DETECT_TO_BUFFER)
                {
                    if((readStatus & RS422_in_RX_STS_MRKSPC) != 0u)
                    {
                        if ((readStatus & RS422_in_RX_STS_ADDR_MATCH) != 0u)
                        {
                            RS422_in_rxAddressDetected = 1u;
                        }
                        else
                        {
                            RS422_in_rxAddressDetected = 0u;
                        }
                    }
                    if(RS422_in_rxAddressDetected != 0u)
                    {   /* Store only addressed data */
                        RS422_in_rxBuffer[RS422_in_rxBufferWrite] = readData;
                        increment_pointer = 1u;
                    }
                }
                else /* Without software addressing */
                {
                    RS422_in_rxBuffer[RS422_in_rxBufferWrite] = readData;
                    increment_pointer = 1u;
                }
            #else  /* Without addressing */
                RS422_in_rxBuffer[RS422_in_rxBufferWrite] = readData;
                increment_pointer = 1u;
            #endif /* (RS422_in_RXHW_ADDRESS_ENABLED) */

                /* Do not increment buffer pointer when skip not addressed data */
                if(increment_pointer != 0u)
                {
                    if(RS422_in_rxBufferLoopDetect != 0u)
                    {   /* Set Software Buffer status Overflow */
                        RS422_in_rxBufferOverflow = 1u;
                    }
                    /* Set next pointer. */
                    RS422_in_rxBufferWrite++;

                    /* Check pointer for a loop condition */
                    if(RS422_in_rxBufferWrite >= RS422_in_RX_BUFFER_SIZE)
                    {
                        RS422_in_rxBufferWrite = 0u;
                    }

                    /* Detect pre-overload condition and set flag */
                    if(RS422_in_rxBufferWrite == RS422_in_rxBufferRead)
                    {
                        RS422_in_rxBufferLoopDetect = 1u;
                        /* When Hardware Flow Control selected */
                        #if (RS422_in_FLOW_CONTROL != 0u)
                            /* Disable RX interrupt mask, it is enabled when user read data from the buffer using APIs */
                            RS422_in_RXSTATUS_MASK_REG  &= (uint8)~RS422_in_RX_STS_FIFO_NOTEMPTY;
                            CyIntClearPending(RS422_in_RX_VECT_NUM);
                            break; /* Break the reading of the FIFO loop, leave the data there for generating RTS signal */
                        #endif /* (RS422_in_FLOW_CONTROL != 0u) */
                    }
                }
            }
        }while((readStatus & RS422_in_RX_STS_FIFO_NOTEMPTY) != 0u);

        /* User code required at end of ISR (Optional) */
        /* `#START RS422_in_RXISR_END` */

        /* `#END` */

    #ifdef RS422_in_RXISR_EXIT_CALLBACK
        RS422_in_RXISR_ExitCallback();
    #endif /* RS422_in_RXISR_EXIT_CALLBACK */

    #if(CY_PSOC3)
        EA = int_en;
    #endif /* (CY_PSOC3) */
    }
    
#endif /* (RS422_in_RX_INTERRUPT_ENABLED && (RS422_in_RX_ENABLED || RS422_in_HD_ENABLED)) */


#if (RS422_in_TX_INTERRUPT_ENABLED && RS422_in_TX_ENABLED)
    /*******************************************************************************
    * Function Name: RS422_in_TXISR
    ********************************************************************************
    *
    * Summary:
    * Interrupt Service Routine for the TX portion of the UART
    *
    * Parameters:
    *  None.
    *
    * Return:
    *  None.
    *
    * Global Variables:
    *  RS422_in_txBuffer - RAM buffer pointer for transmit data from.
    *  RS422_in_txBufferRead - cyclic index for read and transmit data
    *     from txBuffer, increments after each transmitted byte.
    *  RS422_in_rxBufferWrite - cyclic index for write to txBuffer,
    *     checked to detect available for transmission bytes.
    *
    *******************************************************************************/
    CY_ISR(RS422_in_TXISR)
    {
    #if(CY_PSOC3)
        uint8 int_en;
    #endif /* (CY_PSOC3) */

    #ifdef RS422_in_TXISR_ENTRY_CALLBACK
        RS422_in_TXISR_EntryCallback();
    #endif /* RS422_in_TXISR_ENTRY_CALLBACK */

        /* User code required at start of ISR */
        /* `#START RS422_in_TXISR_START` */

        /* `#END` */

    #if(CY_PSOC3)   /* Make sure nested interrupt is enabled */
        int_en = EA;
        CyGlobalIntEnable;
    #endif /* (CY_PSOC3) */

        while((RS422_in_txBufferRead != RS422_in_txBufferWrite) &&
             ((RS422_in_TXSTATUS_REG & RS422_in_TX_STS_FIFO_FULL) == 0u))
        {
            /* Check pointer wrap around */
            if(RS422_in_txBufferRead >= RS422_in_TX_BUFFER_SIZE)
            {
                RS422_in_txBufferRead = 0u;
            }

            RS422_in_TXDATA_REG = RS422_in_txBuffer[RS422_in_txBufferRead];

            /* Set next pointer */
            RS422_in_txBufferRead++;
        }

        /* User code required at end of ISR (Optional) */
        /* `#START RS422_in_TXISR_END` */

        /* `#END` */

    #ifdef RS422_in_TXISR_EXIT_CALLBACK
        RS422_in_TXISR_ExitCallback();
    #endif /* RS422_in_TXISR_EXIT_CALLBACK */

    #if(CY_PSOC3)
        EA = int_en;
    #endif /* (CY_PSOC3) */
   }
#endif /* (RS422_in_TX_INTERRUPT_ENABLED && RS422_in_TX_ENABLED) */


/* [] END OF FILE */
