/*******************************************************************************
* File Name: RS422_in_PM.c
* Version 2.50
*
* Description:
*  This file provides Sleep/WakeUp APIs functionality.
*
* Note:
*
********************************************************************************
* Copyright 2008-2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#include "RS422_in.h"


/***************************************
* Local data allocation
***************************************/

static RS422_in_BACKUP_STRUCT  RS422_in_backup =
{
    /* enableState - disabled */
    0u,
};



/*******************************************************************************
* Function Name: RS422_in_SaveConfig
********************************************************************************
*
* Summary:
*  This function saves the component nonretention control register.
*  Does not save the FIFO which is a set of nonretention registers.
*  This function is called by the RS422_in_Sleep() function.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Global Variables:
*  RS422_in_backup - modified when non-retention registers are saved.
*
* Reentrant:
*  No.
*
*******************************************************************************/
void RS422_in_SaveConfig(void)
{
    #if(RS422_in_CONTROL_REG_REMOVED == 0u)
        RS422_in_backup.cr = RS422_in_CONTROL_REG;
    #endif /* End RS422_in_CONTROL_REG_REMOVED */
}


/*******************************************************************************
* Function Name: RS422_in_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores the nonretention control register except FIFO.
*  Does not restore the FIFO which is a set of nonretention registers.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Global Variables:
*  RS422_in_backup - used when non-retention registers are restored.
*
* Reentrant:
*  No.
*
* Notes:
*  If this function is called without calling RS422_in_SaveConfig() 
*  first, the data loaded may be incorrect.
*
*******************************************************************************/
void RS422_in_RestoreConfig(void)
{
    #if(RS422_in_CONTROL_REG_REMOVED == 0u)
        RS422_in_CONTROL_REG = RS422_in_backup.cr;
    #endif /* End RS422_in_CONTROL_REG_REMOVED */
}


/*******************************************************************************
* Function Name: RS422_in_Sleep
********************************************************************************
*
* Summary:
*  This is the preferred API to prepare the component for sleep. 
*  The RS422_in_Sleep() API saves the current component state. Then it
*  calls the RS422_in_Stop() function and calls 
*  RS422_in_SaveConfig() to save the hardware configuration.
*  Call the RS422_in_Sleep() function before calling the CyPmSleep() 
*  or the CyPmHibernate() function. 
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Global Variables:
*  RS422_in_backup - modified when non-retention registers are saved.
*
* Reentrant:
*  No.
*
*******************************************************************************/
void RS422_in_Sleep(void)
{
    #if(RS422_in_RX_ENABLED || RS422_in_HD_ENABLED)
        if((RS422_in_RXSTATUS_ACTL_REG  & RS422_in_INT_ENABLE) != 0u)
        {
            RS422_in_backup.enableState = 1u;
        }
        else
        {
            RS422_in_backup.enableState = 0u;
        }
    #else
        if((RS422_in_TXSTATUS_ACTL_REG  & RS422_in_INT_ENABLE) !=0u)
        {
            RS422_in_backup.enableState = 1u;
        }
        else
        {
            RS422_in_backup.enableState = 0u;
        }
    #endif /* End RS422_in_RX_ENABLED || RS422_in_HD_ENABLED*/

    RS422_in_Stop();
    RS422_in_SaveConfig();
}


/*******************************************************************************
* Function Name: RS422_in_Wakeup
********************************************************************************
*
* Summary:
*  This is the preferred API to restore the component to the state when 
*  RS422_in_Sleep() was called. The RS422_in_Wakeup() function
*  calls the RS422_in_RestoreConfig() function to restore the 
*  configuration. If the component was enabled before the 
*  RS422_in_Sleep() function was called, the RS422_in_Wakeup()
*  function will also re-enable the component.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Global Variables:
*  RS422_in_backup - used when non-retention registers are restored.
*
* Reentrant:
*  No.
*
*******************************************************************************/
void RS422_in_Wakeup(void)
{
    RS422_in_RestoreConfig();
    #if( (RS422_in_RX_ENABLED) || (RS422_in_HD_ENABLED) )
        RS422_in_ClearRxBuffer();
    #endif /* End (RS422_in_RX_ENABLED) || (RS422_in_HD_ENABLED) */
    #if(RS422_in_TX_ENABLED || RS422_in_HD_ENABLED)
        RS422_in_ClearTxBuffer();
    #endif /* End RS422_in_TX_ENABLED || RS422_in_HD_ENABLED */

    if(RS422_in_backup.enableState != 0u)
    {
        RS422_in_Enable();
    }
}


/* [] END OF FILE */
