/*******************************************************************************
* File Name: RS422_out_PM.c
* Version 2.50
*
* Description:
*  This file provides Sleep/WakeUp APIs functionality.
*
* Note:
*
********************************************************************************
* Copyright 2008-2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#include "RS422_out.h"


/***************************************
* Local data allocation
***************************************/

static RS422_out_BACKUP_STRUCT  RS422_out_backup =
{
    /* enableState - disabled */
    0u,
};



/*******************************************************************************
* Function Name: RS422_out_SaveConfig
********************************************************************************
*
* Summary:
*  This function saves the component nonretention control register.
*  Does not save the FIFO which is a set of nonretention registers.
*  This function is called by the RS422_out_Sleep() function.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Global Variables:
*  RS422_out_backup - modified when non-retention registers are saved.
*
* Reentrant:
*  No.
*
*******************************************************************************/
void RS422_out_SaveConfig(void)
{
    #if(RS422_out_CONTROL_REG_REMOVED == 0u)
        RS422_out_backup.cr = RS422_out_CONTROL_REG;
    #endif /* End RS422_out_CONTROL_REG_REMOVED */
}


/*******************************************************************************
* Function Name: RS422_out_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores the nonretention control register except FIFO.
*  Does not restore the FIFO which is a set of nonretention registers.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Global Variables:
*  RS422_out_backup - used when non-retention registers are restored.
*
* Reentrant:
*  No.
*
* Notes:
*  If this function is called without calling RS422_out_SaveConfig() 
*  first, the data loaded may be incorrect.
*
*******************************************************************************/
void RS422_out_RestoreConfig(void)
{
    #if(RS422_out_CONTROL_REG_REMOVED == 0u)
        RS422_out_CONTROL_REG = RS422_out_backup.cr;
    #endif /* End RS422_out_CONTROL_REG_REMOVED */
}


/*******************************************************************************
* Function Name: RS422_out_Sleep
********************************************************************************
*
* Summary:
*  This is the preferred API to prepare the component for sleep. 
*  The RS422_out_Sleep() API saves the current component state. Then it
*  calls the RS422_out_Stop() function and calls 
*  RS422_out_SaveConfig() to save the hardware configuration.
*  Call the RS422_out_Sleep() function before calling the CyPmSleep() 
*  or the CyPmHibernate() function. 
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Global Variables:
*  RS422_out_backup - modified when non-retention registers are saved.
*
* Reentrant:
*  No.
*
*******************************************************************************/
void RS422_out_Sleep(void)
{
    #if(RS422_out_RX_ENABLED || RS422_out_HD_ENABLED)
        if((RS422_out_RXSTATUS_ACTL_REG  & RS422_out_INT_ENABLE) != 0u)
        {
            RS422_out_backup.enableState = 1u;
        }
        else
        {
            RS422_out_backup.enableState = 0u;
        }
    #else
        if((RS422_out_TXSTATUS_ACTL_REG  & RS422_out_INT_ENABLE) !=0u)
        {
            RS422_out_backup.enableState = 1u;
        }
        else
        {
            RS422_out_backup.enableState = 0u;
        }
    #endif /* End RS422_out_RX_ENABLED || RS422_out_HD_ENABLED*/

    RS422_out_Stop();
    RS422_out_SaveConfig();
}


/*******************************************************************************
* Function Name: RS422_out_Wakeup
********************************************************************************
*
* Summary:
*  This is the preferred API to restore the component to the state when 
*  RS422_out_Sleep() was called. The RS422_out_Wakeup() function
*  calls the RS422_out_RestoreConfig() function to restore the 
*  configuration. If the component was enabled before the 
*  RS422_out_Sleep() function was called, the RS422_out_Wakeup()
*  function will also re-enable the component.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Global Variables:
*  RS422_out_backup - used when non-retention registers are restored.
*
* Reentrant:
*  No.
*
*******************************************************************************/
void RS422_out_Wakeup(void)
{
    RS422_out_RestoreConfig();
    #if( (RS422_out_RX_ENABLED) || (RS422_out_HD_ENABLED) )
        RS422_out_ClearRxBuffer();
    #endif /* End (RS422_out_RX_ENABLED) || (RS422_out_HD_ENABLED) */
    #if(RS422_out_TX_ENABLED || RS422_out_HD_ENABLED)
        RS422_out_ClearTxBuffer();
    #endif /* End RS422_out_TX_ENABLED || RS422_out_HD_ENABLED */

    if(RS422_out_backup.enableState != 0u)
    {
        RS422_out_Enable();
    }
}


/* [] END OF FILE */
